<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        //appraisal_reviews
        Schema::table('appraisal_reviews', function (Blueprint $table) {
            $table->date('appraisal_date')->nullable();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('appraisal_reviews', function (Blueprint $table) {
            $table->dropColumn('appraisal_date');
        });
    }
};
